@@ -1,9 +1,8 @@
 (**************************************************************************)
 (*    Lablgtk - Examples                                                  *)
 (*                                                                        *)
-(*    There is no specific licensing policy, but you may freely           *)
-(*    take inspiration from the code, and copy parts of it in your        *)
-(*    application.                                                        *)
+(*    This code is in the public domain.                                  *)
+(*    You may freely copy parts of it in your application.                *)
 (*                                                                        *)
 (**************************************************************************)
 
@@ -11,17 +10,20 @@
 
 open StdLabels
 
-let file_dialog ~title ~callback ?filename () =
-  let sel =
-    GWindow.file_selection ~title ~modal:true ?filename () in
-  sel#cancel_button#connect#clicked ~callback:sel#destroy;
-  sel#ok_button#connect#clicked ~callback:
-    begin fun () ->
-      let name = sel#filename in
-      sel#destroy ();
-      callback name
-    end;
-  sel#show ()
+type action = [`OPEN|`SAVE|`DELETE_EVENT|`CANCEL]
+
+let file_dialog ~(action:[`OPEN|`SAVE]) ~callback ?filename () =
+  let dialog =
+    GWindow.file_chooser_dialog ~action:(action :> GtkEnums.file_chooser_action)
+      ~modal:true ?filename () in
+  dialog#add_button_stock `CANCEL `CANCEL ;
+  dialog#add_select_button_stock (action :> GtkStock.id) (action :> action)  ;
+  begin match dialog#run () with
+  | `OPEN | `SAVE ->
+      begin match dialog#filename with None -> () | Some s -> callback s end
+  | `DELETE_EVENT | `CANCEL -> ()
+  end ;
+  dialog#destroy ()
 
 let input_channel b ic =
   let buf = Bytes.create 1024 and len = ref 0 in
@@ -51,10 +53,10 @@ class editor ?packing ?show () = object (self)
       n_buff#place_cursor n_buff#start_iter
     with _ -> prerr_endline "Load failed"
 
-  method open_file () = file_dialog ~title:"Open" ~callback:self#load_file ()
+  method open_file () = file_dialog ~action:`OPEN ~callback:self#load_file ()
 
   method save_dialog () =
-    file_dialog ~title:"Save" ?filename
+    file_dialog ~action:`SAVE ?filename
       ~callback:(fun file -> self#output ~file) ()
 
   method save_file () =
@@ -73,6 +75,7 @@ class editor ?packing ?show () = object (self)
     with _ -> prerr_endline "Save failed"
 end
 
+let _ = GMain.init ()
 let window = GWindow.window ~width:500 ~height:300 ~title:"editor" ()
 let vbox = GPack.vbox ~packing:window#add ()
 
