@@ -1,9 +1,8 @@
 (**************************************************************************)
 (*    Lablgtk - Examples                                                  *)
 (*                                                                        *)
-(*    There is no specific licensing policy, but you may freely           *)
-(*    take inspiration from the code, and copy parts of it in your        *)
-(*    application.                                                        *)
+(*    This code is in the public domain.                                  *)
+(*    You may freely copy parts of it in your application.                *)
 (*                                                                        *)
 (**************************************************************************)
 
@@ -34,6 +33,7 @@ let da = GMisc.drawing_area ~packing:w#add ()
 let dw = da#misc#realize (); new GDraw.drawable da#misc#window
 
 let () =
+  GMain.init ();
   da#event#connect#expose (fun _ -> dw#put_pixmap ~x:0 ~y:0 pm; true);
   w#connect#destroy GMain.quit;
   w#show ();
