@@ -1,9 +1,8 @@
 (**************************************************************************)
 (*    Lablgtk - Examples                                                  *)
 (*                                                                        *)
-(*    There is no specific licensing policy, but you may freely           *)
-(*    take inspiration from the code, and copy parts of it in your        *)
-(*    application.                                                        *)
+(*    This code is in the public domain.                                  *)
+(*    You may freely copy parts of it in your application.                *)
 (*                                                                        *)
 (**************************************************************************)
 
@@ -73,7 +72,7 @@ end
 
 (* GUI *)
 
-open GMain
+let _ = GMain.init ()
 
 (* Toplevel window *)
 
@@ -205,6 +204,6 @@ let game = new game ~frame ~label ~statusbar:bar
 (* Start *)
 
 let _ =
-  window#connect#destroy ~callback:Main.quit;
+  window#connect#destroy ~callback:GMain.quit;
   window#show ();
-  Main.main ()
+  GMain.main ()
