@@ -20,9 +20,6 @@
 (*                                                                        *)
 (**************************************************************************)
 
-external init : unit -> unit = "ml_gtkaction_init"
-let () = init ()
-
 module GtkAction = GtkActionProps
 open GtkAction
 
@@ -40,15 +37,19 @@ class action_skel obj = object
   method activate () = Action.activate obj
   method is_sensitive = Action.is_sensitive obj
   method is_visible = Action.is_visible obj
+(*
   method connect_proxy w = Action.connect_proxy obj (GObj.as_widget w)
   method disconnect_proxy w = Action.disconnect_proxy obj (GObj.as_widget w)
+*)
   method get_proxies = List.map (new GObj.widget) (Action.get_proxies obj)
   method connect_accelerator () = Action.connect_accelerator obj
   method disconnect_accelerator () = Action.disconnect_accelerator obj
   method set_accel_path = Action.set_accel_path obj
   method set_accel_group = Action.set_accel_group obj
+(*
   method block_activate_from (w : GObj.widget) = Action.block_activate_from obj w#as_widget
   method unblock_activate_from (w : GObj.widget) = Action.unblock_activate_from obj w#as_widget
+*)
 end
 
 class action obj = object
@@ -231,7 +232,7 @@ class ui_manager obj = object
   method private obj = obj
   inherit OgtkActionProps.ui_manager_props
   method connect = new ui_manager_signals obj
-
+  method as_ui_manager = (obj:> Gtk.ui_manager Gtk.obj)
   method insert_action_group (g : action_group) = 
     UIManager.insert_action_group obj g#as_group
   method remove_action_group (g : action_group) =
