@@ -20,7 +20,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: gObj.mli 1454 2009-05-12 10:19:38Z garrigue $ *)
+(* $Id$ *)
 
 open Gtk
 
@@ -48,7 +48,9 @@ class ['a] gobject_signals : 'a obj ->
     val after : bool
     method after : 'b
     method private connect :
-        'c. ('a,'c) GtkSignal.t -> callback:'c -> GtkSignal.id
+      'c. ('a,'c) GtkSignal.t -> callback:'c -> GtkSignal.id
+    method private notify :
+      'b. ('a, 'b) Gobject.property -> callback:('b -> unit) -> GtkSignal.id
   end
 
 (** {3 GtkObject} *)
@@ -60,24 +62,14 @@ class type ['a] objvar = object
   *)
 end
 
-class gtkobj : ([> `gtk] as 'a) obj ->
+class gtkobj : 'a obj ->
   object
     val obj : 'a obj
-    method destroy : unit -> unit
     method get_oid : int
   end
 
-class gtkobj_signals_impl : ([>`gtk] as 'a) obj ->
-  object ('b)
-    inherit ['a] gobject_signals
-    method destroy : callback:(unit -> unit) -> GtkSignal.id
-  end
-
 class type gtkobj_signals =
-  object ('a)
-    method after : 'a
-    method destroy : callback:(unit -> unit) -> GtkSignal.id
-  end
+  object ('a) method after : 'a end
 
 (** {3 GtkWidget} *)
 
@@ -91,7 +83,6 @@ class event_signals : [> widget] obj ->
     method button_press : callback:(GdkEvent.Button.t -> bool) -> GtkSignal.id
     method button_release :
 	callback:(GdkEvent.Button.t -> bool) -> GtkSignal.id
-    method client : callback:(GdkEvent.Client.t -> bool) -> GtkSignal.id
     method configure : callback:(GdkEvent.Configure.t -> bool) -> GtkSignal.id
     method delete : callback:([`DELETE] Gdk.event -> bool) -> GtkSignal.id
     method destroy : callback:([`DESTROY] Gdk.event -> bool) -> GtkSignal.id
@@ -133,7 +124,6 @@ class event_ops : [> widget] obj ->
     method add : Gdk.Tags.event_mask list -> unit
     method connect : event_signals
     method send : GdkEvent.any -> bool
-    method set_extensions : Gdk.Tags.extension_mode -> unit
   end
 
 (** @gtkdoc gtk GtkStyle *)
@@ -143,24 +133,48 @@ class style : Gtk.style ->
     method as_style : Gtk.style
     method base : Gtk.Tags.state_type -> Gdk.color
     method bg : Gtk.Tags.state_type -> Gdk.color
+(*
     method colormap : Gdk.colormap
+*)
     method copy : 'a
     method dark : Gtk.Tags.state_type -> Gdk.color
     method fg : Gtk.Tags.state_type -> Gdk.color
+(*
     method font : Gdk.font
+*)
     method light : Gtk.Tags.state_type -> Gdk.color
     method mid : Gtk.Tags.state_type -> Gdk.color
     method set_bg : (Gtk.Tags.state_type * GDraw.color) list -> unit
     method set_base : (Gtk.Tags.state_type * GDraw.color) list -> unit
     method set_dark : (Gtk.Tags.state_type * GDraw.color) list -> unit
     method set_fg : (Gtk.Tags.state_type * GDraw.color) list -> unit
+(*
     method set_font : Gdk.font -> unit
+*)
     method set_light : (Gtk.Tags.state_type * GDraw.color) list -> unit
     method set_mid : (Gtk.Tags.state_type * GDraw.color) list -> unit
     method set_text : (Gtk.Tags.state_type * GDraw.color) list -> unit
     method text : Gtk.Tags.state_type -> Gdk.color
   end
 
+(** @gtkdoc gtk GtkCssProvider *)
+
+class css_provider: Gtk.css_provider ->
+  object
+    val prov : Gtk.css_provider
+    method as_css_provider : Gtk.css_provider
+    method load_from_data: string -> unit
+  end
+
+val css_provider: unit -> css_provider
+
+(** @gtkdoc gtk GtkStyleContext *)
+class style_context: Gtk.style_context ->
+  object
+    val ctxt : Gtk.style_context
+    method add_provider: css_provider -> int -> unit
+  end
+
 (** @gtkdoc gtk gtk-Selections *)
 class selection_data :
   Gtk.selection_data ->
@@ -184,6 +198,7 @@ class selection_context :
   end
 
 (** @gtkdoc gtk gtk-Drag-and-Drop *)
+
 class drag_ops : Gtk.widget obj ->
   object
     method connect : drag_signals
@@ -196,7 +211,6 @@ class drag_ops : Gtk.widget obj ->
     method source_set :
       ?modi:Gdk.Tags.modifier list ->
       ?actions:Gdk.Tags.drag_action list -> target_entry list -> unit
-    method source_set_icon : ?colormap:Gdk.colormap -> GDraw.pixmap -> unit
     method source_unset : unit -> unit
     method unhighlight : unit -> unit
   end
@@ -207,46 +221,48 @@ and misc_ops : Gtk.widget obj ->
     inherit gobject_ops
     val obj : Gtk.widget obj
     method activate : unit -> bool
-    method add_accelerator :
-      sgn:(Gtk.widget, unit -> unit) GtkSignal.t ->
+    method add_accelerator : 'a.
+      sgn:('a, unit -> unit) GtkSignal.t ->
       group:accel_group -> ?modi:Gdk.Tags.modifier list ->
       ?flags:Tags.accel_flag list -> Gdk.keysym -> unit
     method add_selection_target :
       target:string -> ?info:int -> Gdk.atom -> unit
     method allocation : rectangle
     method clear_selection_targets : Gdk.atom -> unit
-    method colormap : Gdk.colormap
     method connect : misc_signals
     method convert_selection : target:string -> ?time:int32 -> Gdk.atom -> bool
-    method create_pango_context : GPango.context_rw
-    method draw : Gdk.Rectangle.t option -> unit
-    method get_flag : Tags.widget_flags -> bool
+    method create_pango_context : GPango.context
+    method draw : Gdk.cairo -> unit
     method grab_default : unit -> unit
     method grab_focus : unit -> unit
     method grab_selection : ?time:int32 -> Gdk.atom -> bool
     method has_tooltip : bool
     method hide : unit -> unit
-    method hide_all : unit -> unit
     method intersect : Gdk.Rectangle.t -> Gdk.Rectangle.t option
     method is_ancestor : widget -> bool
     method map : unit -> unit
+    (* Deprecated since 3.0 *)
     method modify_bg : (Gtk.Tags.state_type * GDraw.color) list -> unit
     method modify_base : (Gtk.Tags.state_type * GDraw.color) list -> unit
     method modify_fg : (Gtk.Tags.state_type * GDraw.color) list -> unit
     method modify_text : (Gtk.Tags.state_type * GDraw.color) list -> unit
-    method modify_font : Pango.font_description -> unit
+    method modify_font : GPango.font_description -> unit
     method modify_font_by_name : string -> unit
+    (* End deprecated since 3.0 *)
+    method style_context: style_context
     method name : string
     method parent : widget option
     method pango_context : GPango.context
     method pointer : int * int
+    method queue_draw : unit -> unit
+    method queue_draw_area : int -> int -> int -> int -> unit
     method realize : unit -> unit
     method remove_accelerator :
       group:accel_group -> ?modi:Gdk.Tags.modifier list -> Gdk.keysym -> unit
     method render_icon :
-       ?detail:string -> size:Gtk.Tags.icon_size ->
-       GtkStock.id -> GdkPixbuf.pixbuf
+       size:Gtk.Tags.icon_size -> GtkStock.id -> GdkPixbuf.pixbuf
     method reparent : widget -> unit
+    method sensitive : bool
     method set_app_paintable : bool -> unit
     method set_can_default : bool -> unit
     method set_can_focus : bool -> unit
@@ -255,9 +271,8 @@ and misc_ops : Gtk.widget obj ->
     method set_name : string -> unit
     method set_sensitive : bool -> unit
     method set_size_chars :
-      ?desc:Pango.font_description ->
+      ?desc:GPango.font_description ->
       ?lang:string -> ?width:int -> ?height:int -> unit -> unit
-    method set_state : Tags.state_type -> unit
     method set_style : style -> unit
     method set_size_request : ?width:int -> ?height:int -> unit -> unit
     method set_tooltip_markup : string -> unit
@@ -282,19 +297,95 @@ and widget : ([> Gtk.widget] as 'a) obj ->
   object
     inherit gtkobj
     val obj : 'a obj
+    method app_paintable : bool
     method as_widget : Gtk.widget obj
+    method can_default : bool
+    method can_focus : bool
     method coerce : widget
+    method composite_child : bool
+    method destroy : unit -> unit
     method drag : drag_ops
+    method events : GdkEnums.event_mask list
+    method expand : bool
+    method focus_on_click : bool
+    method halign : GtkEnums.align
+    method has_default : bool
+    method has_focus : bool
+    method has_tooltip : bool
+    method height_request : int
+    method hexpand : bool
+    method hexpand_set : bool
+    method is_focus : bool
+    method margin : int
+    method margin_bottom : int
+    method margin_end : int
+    method margin_left : int
+    method margin_right : int
+    method margin_start : int
+    method margin_top : int
     method misc : misc_ops
+    method destroy : unit -> unit
+    method name : string
+    method no_show_all : bool
+    method opacity : float
+    method parent : Gtk.container Gtk.obj option
+    method receives_default : bool
+    method scale_factor : int
+    method sensitive : bool
+    method set_app_paintable : bool -> unit
+    method set_can_default : bool -> unit
+    method set_can_focus : bool -> unit
+    method set_events : GdkEnums.event_mask list -> unit
+    method set_expand : bool -> unit
+    method set_focus_on_click : bool -> unit
+    method set_halign : GtkEnums.align -> unit
+    method set_has_default : bool -> unit
+    method set_has_focus : bool -> unit
+    method set_has_tooltip : bool -> unit
+    method set_height_request : int -> unit
+    method set_hexpand : bool -> unit
+    method set_hexpand_set : bool -> unit
+    method set_is_focus : bool -> unit
+    method set_margin : int -> unit
+    method set_margin_bottom : int -> unit
+    method set_margin_end : int -> unit
+    method set_margin_left : int -> unit
+    method set_margin_right : int -> unit
+    method set_margin_start : int -> unit
+    method set_margin_top : int -> unit
+    method set_name : string -> unit
+    method set_no_show_all : bool -> unit
+    method set_opacity : float -> unit
+    method set_parent : Gtk.container Gtk.obj option -> unit
+    method set_receives_default : bool -> unit
+    method set_sensitive : bool -> unit
+    method set_style : Gtk.style -> unit
+    method set_tooltip_markup : string -> unit
+    method set_tooltip_text : string -> unit
+    method set_valign : GtkEnums.align -> unit
+    method set_vexpand : bool -> unit
+    method set_vexpand_set : bool -> unit
+    method set_visible : bool -> unit
+    method set_width_request : int -> unit
+    method style : Gtk.style
+    method tooltip_markup : string
+    method tooltip_text : string
+    method valign : GtkEnums.align
+    method vexpand : bool
+    method vexpand_set : bool
+    method visible : bool
+    method width_request : int
   end
 
 (** @gtkdoc gtk GtkWidget *)
 and misc_signals : Gtk.widget obj ->
   object ('b)
-    inherit gtkobj_signals 
+    inherit gtkobj_signals
+    method destroy : callback:(unit -> unit) -> GtkSignal.id
     method hide : callback:(unit -> unit) -> GtkSignal.id
     method map : callback:(unit -> unit) -> GtkSignal.id
     method parent_set : callback:(widget option -> unit) -> GtkSignal.id
+    method draw : callback:(Gdk.cairo -> bool) -> GtkSignal.id
     method query_tooltip :
       callback:(x:int -> y:int -> kbd:bool -> tooltip -> bool) -> GtkSignal.id
     method realize : callback:(unit -> unit) -> GtkSignal.id
@@ -320,8 +411,6 @@ and drag_context :
     method context : Gdk.drag_context
     method finish : success:bool -> del:bool -> time:int32 -> unit
     method source_widget : widget 
-    method set_icon_pixmap :
-      ?colormap:Gdk.colormap -> GDraw.pixmap -> hot_x:int -> hot_y:int -> unit
     method set_icon_widget : widget -> hot_x:int -> hot_y:int -> unit
     method status : ?time:int32 -> Gdk.Tags.drag_action option -> unit
     method suggested_action : Gdk.Tags.drag_action
@@ -364,7 +453,11 @@ class ['a] widget_impl : ([> Gtk.widget] as 'a) obj ->
   end
 
 (** @gtkdoc gtk GtkWidget *)
-class type widget_signals = gtkobj_signals
+class type widget_signals =
+  object
+    inherit gtkobj_signals
+    method destroy : callback:(unit -> unit) -> GtkSignal.id
+  end
 
 (** @gtkdoc gtk GtkWidget *)
 class widget_signals_impl : ([> Gtk.widget] as 'a) obj ->
