@@ -305,6 +305,7 @@ class view_column : tree_view_column obj ->
     method alignment : float
     method clickable : bool
     method connect : view_column_signals
+    method expand : bool
     method fixed_width : int
     method get_sort_column_id : int
     method max_width : int
@@ -313,6 +314,7 @@ class view_column : tree_view_column obj ->
     method resizable : bool
     method set_alignment : float -> unit
     method set_clickable : bool -> unit
+    method set_expand : bool -> unit
     method set_fixed_width : int -> unit
     method set_max_width : int -> unit
     method set_min_width : int -> unit
@@ -361,9 +363,6 @@ class view_signals : [> tree_view] obj ->
     method select_cursor_parent : callback:(unit -> bool) -> GtkSignal.id
     method select_cursor_row :
       callback:(start_editing:bool -> bool) -> GtkSignal.id
-    method set_scroll_adjustments :
-      callback:(GData.adjustment option -> GData.adjustment option -> unit) ->
-      GtkSignal.id
     method start_interactive_search : callback:(unit -> bool) -> GtkSignal.id
     method test_collapse_row :
       callback:(tree_iter -> tree_path -> bool) -> GtkSignal.id
@@ -533,7 +532,9 @@ type cell_properties_text =
   | `TEXT of string
   | `UNDERLINE of Pango.Tags.underline
   | `VARIANT of Pango.Tags.variant
-  | `WEIGHT of Pango.Tags.weight ]
+  | `WEIGHT of Pango.Tags.weight
+  | `WRAP_MODE of Pango.Tags.wrap_mode
+  | `WRAP_WIDTH of int ]
 type cell_properties_toggle =
   [ cell_properties
   | `ACTIVATABLE of bool
@@ -577,7 +578,7 @@ class virtual ['a, 'b] cell_renderer_impl : ([>Gtk.cell_renderer] as 'a) obj ->
 class cell_renderer_pixbuf : Gtk.cell_renderer_pixbuf obj ->
   object
     inherit[Gtk.cell_renderer_pixbuf,cell_properties_pixbuf] cell_renderer_skel
-    method connect : GObj.gtkobj_signals_impl
+    method connect : GObj.gtkobj_signals
   end
 
 (** @gtkdoc gtk GtkCellRendererText *)
@@ -614,8 +615,9 @@ class cell_renderer_toggle : Gtk.cell_renderer_toggle obj ->
     @gtkdoc gtk GtkCellRendererProgress *)
 class cell_renderer_progress : Gtk.cell_renderer_progress obj ->
   object
-    inherit[Gtk.cell_renderer_progress,cell_properties_progress] cell_renderer_skel
-    method connect : GObj.gtkobj_signals_impl
+    inherit[Gtk.cell_renderer_progress,cell_properties_progress]
+        cell_renderer_skel
+    method connect : GObj.gtkobj_signals
   end
 
 (** @since GTK 2.6
@@ -735,7 +737,7 @@ class icon_view :
     method spacing : int
     method set_spacing : int -> unit
 
-    method get_path_at_pos : int -> int -> Gtk.tree_path
+    method get_path_at_pos : int -> int -> Gtk.tree_path option
     method selected_foreach : (Gtk.tree_path -> unit) -> unit
     method get_selected_items : Gtk.tree_path list
     method path_is_selected : Gtk.tree_path -> bool
