@@ -1,4 +1,26 @@
-(* $Id: gtkBase.ml,v 1.49 2005/02/18 04:21:30 garrigue Exp $ *)
+(**************************************************************************)
+(*                Lablgtk                                                 *)
+(*                                                                        *)
+(*    This program is free software; you can redistribute it              *)
+(*    and/or modify it under the terms of the GNU Library General         *)
+(*    Public License as published by the Free Software Foundation         *)
+(*    version 2, with the exception described in file COPYING which       *)
+(*    comes with the library.                                             *)
+(*                                                                        *)
+(*    This program is distributed in the hope that it will be useful,     *)
+(*    but WITHOUT ANY WARRANTY; without even the implied warranty of      *)
+(*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the       *)
+(*    GNU Library General Public License for more details.                *)
+(*                                                                        *)
+(*    You should have received a copy of the GNU Library General          *)
+(*    Public License along with this program; if not, write to the        *)
+(*    Free Software Foundation, Inc., 59 Temple Place, Suite 330,         *)
+(*    Boston, MA 02111-1307  USA                                          *)
+(*                                                                        *)
+(*                                                                        *)
+(**************************************************************************)
+
+(* $Id$ *)
 
 open Gaux
 open Gobject
@@ -9,16 +31,6 @@ open GtkBaseProps
 module Object = struct
   include GtkObject
   let try_cast = Gobject.try_cast
-  external destroy : [>`gtk] obj -> unit = "ml_gtk_object_destroy"
-  external get_flags : [>`gtk] obj -> int = "ml_GTK_OBJECT_FLAGS"
-  let get_flag obj wf =
-    (get_flags obj) land (Gpointer.encode_variant GtkEnums.widget_flags wf)
-      <> 0
-  module S = struct
-    open GtkSignal
-    let destroy =
-      { name = "destroy"; classe = `gtk; marshaller = marshal_unit }
-  end
 end
 
 module Widget = struct
@@ -35,15 +47,14 @@ module Widget = struct
   external show_now : [>`widget] obj -> unit = "ml_gtk_widget_show_now"
   external show_all : [>`widget] obj -> unit = "ml_gtk_widget_show_all"
   external hide : [>`widget] obj -> unit = "ml_gtk_widget_hide"
-  external hide_all : [>`widget] obj -> unit = "ml_gtk_widget_hide_all"
   external map : [>`widget] obj -> unit = "ml_gtk_widget_map"
   external unmap : [>`widget] obj -> unit = "ml_gtk_widget_unmap"
   external realize : [>`widget] obj -> unit = "ml_gtk_widget_realize"
   external unrealize : [>`widget] obj -> unit = "ml_gtk_widget_unrealize"
   external queue_draw : [>`widget] obj -> unit = "ml_gtk_widget_queue_draw"
   external queue_resize : [>`widget] obj -> unit = "ml_gtk_widget_queue_resize"
-  external draw : [>`widget] obj -> Gdk.Rectangle.t option -> unit
-      = "ml_gtk_widget_draw"
+  external draw : [>`widget] obj -> Gdk.cairo -> unit = "ml_gtk_widget_draw"
+  external queue_draw_area : [>`widget] obj -> int -> int -> int -> int -> unit = "ml_gtk_widget_queue_draw_area"
 (*
   external draw_focus : [>`widget] obj -> unit
       = "ml_gtk_widget_draw_focus"
@@ -63,24 +74,25 @@ module Widget = struct
   external intersect :
       [>`widget] obj -> Gdk.Rectangle.t -> Gdk.Rectangle.t option
       = "ml_gtk_widget_intersect"
-  external set_state : [>`widget] obj -> state_type -> unit
+  (*external set_state : [>`widget] obj -> state_type -> unit
       = "ml_gtk_widget_set_state"
   external set_uposition : [>`widget] obj -> x:int -> y:int -> unit
-      = "ml_gtk_widget_set_uposition"
+      = "ml_gtk_widget_set_uposition"*)
   external add_events : [>`widget] obj -> Gdk.Tags.event_mask list -> unit
       = "ml_gtk_widget_add_events"
   external get_toplevel : [>`widget] obj -> widget obj
       = "ml_gtk_widget_get_toplevel"
   external get_ancestor : [>`widget] obj -> g_type -> widget obj
       = "ml_gtk_widget_get_ancestor"
-  external get_colormap : [>`widget] obj -> Gdk.colormap
-      = "ml_gtk_widget_get_colormap"
+  (*external get_colormap : [>`widget] obj -> Gdk.colormap
+      = "ml_gtk_widget_get_colormap"*)
   external get_visual : [>`widget] obj -> Gdk.visual
       = "ml_gtk_widget_get_visual"
   external get_pointer : [>`widget] obj -> int * int
       = "ml_gtk_widget_get_pointer"
   external is_ancestor : [>`widget] obj -> [>`widget] obj -> bool
       = "ml_gtk_widget_is_ancestor"
+  (* Deprecated since 3.0 *)
   external ensure_style : [>`widget] obj -> unit
       = "ml_gtk_widget_ensure_style"
   external modify_fg : [>`widget] obj -> state_type -> Gdk.color -> unit
@@ -93,14 +105,17 @@ module Widget = struct
       = "ml_gtk_widget_modify_base"
   external modify_font : [>`widget] obj -> Pango.font_description -> unit
       = "ml_gtk_widget_modify_font"
+  (* End deprecated since 3.0 *)
+  external get_style_context : [>`widget] obj -> style_context
+      = "ml_gtk_widget_get_style_context"
   external get_pango_context : [>`widget] obj -> Pango.context
       = "ml_gtk_widget_get_pango_context"
   external create_pango_context : [>`widget] obj -> Pango.context
       = "ml_gtk_widget_create_pango_context"
-  external render_icon : 
-      [>`widget] obj -> string -> 
-      Gtk.Tags.icon_size -> string option -> GdkPixbuf.pixbuf
-      = "ml_gtk_widget_render_icon"
+  external render_icon :
+      [>`widget] obj -> string ->
+      Gtk.Tags.icon_size -> GdkPixbuf.pixbuf
+      = "ml_gtk_widget_render_icon_pixbuf"
   external add_accelerator :
       ([>`widget] as 'a) obj -> sgn:('a,unit->unit) GtkSignal.t ->
       accel_group -> key:Gdk.keysym -> ?modi:Gdk.Tags.modifier list ->
@@ -123,14 +138,14 @@ module Widget = struct
       = "ml_gtk_widget_accelerators_locked"
 *)
   external window : [>`widget] obj -> Gdk.window
-      = "ml_GtkWidget_window"
+      = "ml_gtk_widget_get_window"
   external allocation : [>`widget] obj -> rectangle
-      = "ml_gtk_widget_allocation"
-  external set_colormap : [>`widget] obj -> Gdk.colormap -> unit
-      = "ml_gtk_widget_set_colormap"
+      = "ml_gtk_widget_get_allocation"
+  (* external set_colormap : [>`widget] obj -> Gdk.colormap -> unit
+      = "ml_gtk_widget_set_colormap" *)
   external set_visual : [>`widget] obj -> Gdk.visual -> unit
       = "ml_gtk_widget_set_visual"
-  external set_default_colormap : Gdk.colormap -> unit
+  (* external set_default_colormap : Gdk.colormap -> unit
       = "ml_gtk_widget_set_default_colormap"
   external set_default_visual : Gdk.visual -> unit
       = "ml_gtk_widget_set_default_visual"
@@ -145,9 +160,34 @@ module Widget = struct
   external pop_colormap : unit -> unit
       = "ml_gtk_widget_pop_colormap"
   external pop_visual : unit -> unit
-      = "ml_gtk_widget_pop_visual"
+      = "ml_gtk_widget_pop_visual" *)
+  
+  (** @since GTK 2.12 *)
+  module Tooltip = struct
+    external get_markup : [>`widget] obj -> string
+      = "ml_gtk_widget_get_tooltip_markup"
+    external set_markup : [>`widget] obj -> string -> unit
+      = "ml_gtk_widget_set_tooltip_markup"
+    external get_text : [>`widget] obj -> string
+      = "ml_gtk_widget_get_tooltip_text"
+    external set_text : [>`widget] obj -> string -> unit
+      = "ml_gtk_widget_set_tooltip_text"
+    external get_window : [>`widget] obj -> Gtk.window obj
+      = "ml_gtk_widget_get_tooltip_window"
+    external set_window : [>`widget] obj -> [>`window] obj -> unit
+      = "ml_gtk_widget_set_tooltip_window"
+    external get_has_tooltip : [>`widget] obj -> bool
+      = "ml_gtk_widget_get_has_tooltip"
+    external set_has_tooltip : [>`widget] obj -> bool -> unit
+      = "ml_gtk_widget_set_has_tooltip"
+    external trigger_query : [>`widget] obj -> unit
+      = "ml_gtk_widget_trigger_tooltip_query"
+  end
+
   module Signals = struct
     open GtkSignal
+    let destroy =
+      { name = "destroy"; classe = `widget; marshaller = marshal_unit }
     let marshal f _ = function
       | `OBJECT(Some p) :: _ -> f (cast p)
       |	_ -> invalid_arg "GtkBase.Widget.Signals.marshal"
@@ -224,9 +264,6 @@ module Widget = struct
       let proximity_out : ([>`widget], GdkEvent.Proximity.t -> bool) t =
 	{ name = "proximity_out_event"; classe = `widget;
           marshaller = marshal }
-      let client : ([>`widget], GdkEvent.Client.t -> bool) t =
-	{ name = "client_event"; classe = `widget;
-          marshaller = marshal }
       let visibility_notify : ([>`widget], GdkEvent.Visibility.t -> bool) t =
 	{ name = "visibility_notify_event"; classe = `widget;
           marshaller = marshal }
@@ -237,31 +274,25 @@ module Widget = struct
   end
 end
 
-module Container = struct
-  include Container
-  let make_params ~cont pl ?border_width =
-    Widget.size_params pl ~cont:(fun p ->
-      cont (Property.may_cons P.border_width border_width p))
-
-  let children w =
-    let l = ref [] in
-    foreach w ~f:(fun c -> l := c :: !l);
-    List.rev !l
-end
+module Orientable = Orientable
 
 module Bin = Bin
 
-module Item = Item
-
 (* Clipboard provides high-level access to Selection *)
 module Clipboard = struct
   external get : Gdk.atom -> clipboard = "ml_gtk_clipboard_get"
   external clear : clipboard -> unit = "ml_gtk_clipboard_clear"
   external set_text : clipboard -> string -> unit = "ml_gtk_clipboard_set_text"
+  external set_image : clipboard -> GdkPixbuf.pixbuf -> unit
+      = "ml_gtk_clipboard_set_image"
   external wait_for_contents : clipboard -> target:Gdk.atom -> selection_data
       = "ml_gtk_clipboard_wait_for_contents"
   external wait_for_text : clipboard -> string option
       = "ml_gtk_clipboard_wait_for_text"
+  external wait_for_image : clipboard -> GdkPixbuf.pixbuf option
+      = "ml_gtk_clipboard_wait_for_image"
+  external wait_for_targets : clipboard -> Gdk.atom list
+      = "ml_gtk_clipboard_wait_for_targets"
   external request_contents :
       clipboard -> target:Gdk.atom -> callback:(selection_data -> unit) -> unit
       = "ml_gtk_clipboard_request_contents"
@@ -273,13 +304,13 @@ end
 (* Use of Selection is deprecated: rather use simpler Clipboard module *)
 module Selection = struct
   external selection : selection_data -> Gdk.atom
-      = "ml_gtk_selection_data_selection"
+      = "ml_gtk_selection_data_get_selection"
   external target : selection_data -> Gdk.atom
-      = "ml_gtk_selection_data_target"
+      = "ml_gtk_selection_data_get_target"
   external seltype : selection_data -> Gdk.atom
-      = "ml_gtk_selection_data_type"
+      = "ml_gtk_selection_data_get_data_type"
   external format : selection_data -> int
-      = "ml_gtk_selection_data_format"
+      = "ml_gtk_selection_data_get_format"
   external get_data : selection_data -> string
       = "ml_gtk_selection_data_get_data"       (* May raise Gpointer.null *)
   external set :
@@ -299,6 +330,9 @@ module Selection = struct
   external convert :
     [> `widget] obj -> sel:Gdk.atom -> target:Gdk.atom -> time:int32 -> bool
     = "ml_gtk_selection_convert"
+  external clear_targets :
+    [>`widget] obj -> sel:Gdk.atom -> unit
+    = "ml_gtk_selection_clear_targets"
 end
 
 module DnD = struct
@@ -321,25 +355,34 @@ module DnD = struct
   external set_icon_widget :
       Gdk.drag_context -> [>`widget] obj -> hot_x:int -> hot_y:int -> unit
       = "ml_gtk_drag_set_icon_widget"
-  external set_icon_pixmap :
-      Gdk.drag_context -> colormap:Gdk.colormap ->
-      Gdk.pixmap -> ?mask:Gdk.bitmap -> hot_x:int -> hot_y:int -> unit
-      = "ml_gtk_drag_set_icon_pixmap_bc" "ml_gtk_drag_set_icon_pixmap"
   external set_icon_default : Gdk.drag_context -> unit
       = "ml_gtk_drag_set_icon_default"
-  external set_default_icon :
-      colormap:Gdk.colormap -> Gdk.pixmap ->
-      ?mask:Gdk.bitmap -> hot_x:int -> hot_y:int -> unit
-      = "ml_gtk_drag_set_default_icon"
   external source_set :
       [>`widget] obj -> ?modi:Gdk.Tags.modifier list ->
       targets:target_entry array -> actions:Gdk.Tags.drag_action list -> unit
       = "ml_gtk_drag_source_set"
-  external source_set_icon :
-      [>`widget] obj -> colormap:Gdk.colormap ->
-      Gdk.pixmap -> ?mask:Gdk.bitmap -> unit
-      = "ml_gtk_drag_source_set_icon"
   external source_unset : [>`widget] obj -> unit
       = "ml_gtk_drag_source_unset"
 (*  external dest_handle_event : [>`widget] -> *)
 end
+
+(** @since GTK 2.12 *)
+module Tooltip = struct
+  external set_markup : tooltip -> string -> unit
+      = "ml_gtk_tooltip_set_markup"
+  external set_text : tooltip -> string -> unit
+      = "ml_gtk_tooltip_set_text"
+  external set_icon : tooltip -> GdkPixbuf.pixbuf -> unit
+      = "ml_gtk_tooltip_set_icon"
+  external set_icon_from_stock :
+      tooltip -> string -> Gtk.Tags.icon_size -> unit
+      = "ml_gtk_tooltip_set_icon_from_stock"
+  let set_icon_from_stock tt id =
+    set_icon_from_stock tt (GtkStock.convert_id id)
+  external set_custom : tooltip -> [>`widget] obj -> unit
+      = "ml_gtk_tooltip_set_custom"
+  external trigger_query :  Gdk.display -> unit
+      = "ml_gtk_tooltip_trigger_tooltip_query"
+  external set_tip_area : tooltip -> Gdk.Rectangle.t -> unit
+      = "ml_gtk_tooltip_set_tip_area"
+end
