@@ -32,7 +32,6 @@
 #include <caml/callback.h>
 #include <caml/fail.h>
 #include <caml/intext.h>
-#include <caml/printexc.h>
 
 #include "wrappers.h"
 #include "ml_glib.h"
@@ -67,8 +66,8 @@ static void ml_GdkPixbuf_serialize (value v, unsigned long *wsize_32, unsigned l
   guint len;
   pixels = gdk_pixdata_from_pixbuf (&pixdata, pb, pixbuf_marshal_use_rle);
   stream = gdk_pixdata_serialize (&pixdata, &len);
-  caml_serialize_int_4 (len);
-  caml_serialize_block_1 (stream, len);
+  serialize_int_4 (len);
+  serialize_block_1 (stream, len);
   g_free (stream);
   g_free (pixels);
   *wsize_32 = 4;
@@ -83,9 +82,9 @@ static unsigned long ml_GdkPixbuf_deserialize (void *dst)
   guint8 *stream;
   guint len;
 
-  len = caml_deserialize_uint_4();
+  len = deserialize_uint_4();
   stream = stat_alloc (len);
-  caml_deserialize_block_1 (stream, len);
+  deserialize_block_1 (stream, len);
   gdk_pixdata_deserialize (&pixdata, len, stream, &error);
   if (error) goto out;
   pb = gdk_pixbuf_from_pixdata (&pixdata, TRUE, &error);
@@ -101,7 +100,7 @@ static unsigned long ml_GdkPixbuf_deserialize (void *dst)
       GEnumValue *val   = g_enum_get_value (class, error->code);
       msg = val ? (char*)val->value_name : "";
       g_error_free (error);
-      caml_deserialize_error (msg);
+      deserialize_error (msg);
     }
   return sizeof pb;
 }
@@ -230,48 +229,6 @@ ML_bc8(ml_gdk_pixbuf_copy_area)
 /* Create a sub-region */
 ML_5(gdk_pixbuf_new_subpixbuf, GdkPixbuf_val, Int_val, Int_val, Int_val, Int_val, Val_GdkPixbuf_new)
 
-/* Rendering to a drawable */
-ML_9(gdk_pixbuf_render_threshold_alpha, GdkPixbuf_val, GdkBitmap_val,
-     Int_val, Int_val, Int_val, Int_val, Int_val, Int_val, Int_val, Unit)
-ML_bc9(ml_gdk_pixbuf_render_threshold_alpha)
-ML_12(gdk_pixbuf_render_to_drawable, GdkPixbuf_val, GdkDrawable_val,
-      GdkGC_val, Int_val, Int_val, Int_val, Int_val, Int_val, Int_val,
-      GdkRgbDither_val, Int_val, Int_val, Unit)
-ML_bc12(ml_gdk_pixbuf_render_to_drawable)
-ML_13(gdk_pixbuf_render_to_drawable_alpha, GdkPixbuf_val, GdkDrawable_val,
-      Int_val, Int_val, Int_val, Int_val, Int_val, Int_val,
-      Alpha_mode_val, Int_val, GdkRgbDither_val, Int_val, Int_val, Unit)
-ML_bc13(ml_gdk_pixbuf_render_to_drawable_alpha)
-/* Not available before 2.2
-ML_12(gdk_draw_pixbuf, GdkDrawable_val, GdkGC_val, GdkPixbuf_val,
-      Int_val, Int_val, Int_val, Int_val, Int_val, Int_val,
-      GdkRgbDither_val, Int_val, Int_val, Unit)
-ML_bc12(ml_gdk_draw_pixbuf)
-*/
-
-CAMLprim value ml_gdk_pixbuf_render_pixmap_and_mask (value pixbuf, value thr)
-{
-    CAMLparam0();
-    CAMLlocal2(vpm,vmask);
-    value ret;
-    GdkPixmap *pm;
-    GdkBitmap *mask;
-    gdk_pixbuf_render_pixmap_and_mask(GdkPixbuf_val(pixbuf), &pm, &mask,
-				      Int_val(thr));
-    vpm = Val_GdkPixmap_no_ref(pm);
-    vmask = Val_option(mask,Val_GdkBitmap_no_ref);
-    ret = alloc_small(2,0);
-    Field(ret,0) = vpm;
-    Field(ret,1) = vmask;
-    CAMLreturn(ret);
-}
-
-/* Fetching a region from a drawable */
-ML_9(gdk_pixbuf_get_from_drawable, GdkPixbuf_val, GdkDrawable_val,
-     GdkColormap_val, Int_val, Int_val, Int_val, Int_val, Int_val, Int_val,
-     Unit)
-ML_bc9(ml_gdk_pixbuf_get_from_drawable)
-
 /* Scaling */
 ML_11(gdk_pixbuf_scale, GdkPixbuf_val, GdkPixbuf_val, Int_val, Int_val,
       Int_val, Int_val, Double_val, Double_val, Double_val, Double_val,
@@ -351,7 +308,7 @@ ml_gdkpixbuf_savefunc (const gchar *buf, gsize count, GError **error, gpointer d
   if (Is_exception_result (res))
     {
       g_set_error (error, GDK_PIXBUF_ERROR, GDK_PIXBUF_ERROR_FAILED,
-		   "%s", caml_format_exception(Extract_exception(res)));
+		   "%s", format_caml_exception(Extract_exception(res)));
       return FALSE;
     }
   else
