@@ -29,6 +29,7 @@
 #include <caml/memory.h>
 #include <caml/callback.h>
 #include <caml/fail.h>
+#include <caml/threads.h>
 
 #include "wrappers.h"
 #include "ml_glib.h"
@@ -59,8 +60,10 @@ CAMLexport void ml_g_object_unref_later (GObject *p)
 
 Make_Val_final_pointer(GObject, g_object_ref, ml_g_object_unref_later, 0)
 Make_Val_final_pointer_ext (GObject, _new, Ignore, ml_g_object_unref_later, 20)
+Make_Val_final_pointer_ext(GObject, _sink , g_object_ref_sink,
+                           ml_g_object_unref_later, 20)
 ML_1 (G_TYPE_FROM_INSTANCE, GObject_val, Val_GType)
-// ML_1 (g_object_ref, GObject_val, Unit)
+ML_1 (g_object_ref_sink, GObject_val, Unit)
 CAMLprim value ml_g_object_unref (value val)
 {
     if (Field(val,1)) g_object_unref (GObject_val(val));
@@ -68,7 +71,7 @@ CAMLprim value ml_g_object_unref (value val)
     return Val_unit;
 }
 Make_Extractor(g_object, GObject_val, ref_count, Val_int)
-    
+
 ML_1 (g_object_freeze_notify, GObject_val, Unit)
 ML_1 (g_object_thaw_notify, GObject_val, Unit)
 ML_2 (g_object_notify, GObject_val, String_val, Unit)
@@ -178,7 +181,7 @@ static void notify_destroy(gpointer unit, GClosure *c)
     remove_global_root((value*)&c->data);
 }
 
-static void marshal (GClosure *closure, GValue *ret,
+static void marshal_core (GClosure *closure, GValue *ret,
                      guint nargs, const GValue *args,
                      gpointer hint, gpointer marshall_data)
 {
@@ -194,6 +197,20 @@ static void marshal (GClosure *closure, GValue *ret,
     CAMLreturn0;
 }
 
+static void marshal (GClosure *closure, GValue *ret,
+                     guint nargs, const GValue *args,
+                     gpointer hint, gpointer marshall_data)
+{
+    if (polling) { // https://github.com/garrigue/lablgtk/issues/141
+      caml_leave_blocking_section();
+      polling = 0;
+      marshal_core(closure, ret, nargs, args, hint, marshall_data);
+      polling = 1;
+      caml_enter_blocking_section();
+    } else
+      marshal_core(closure, ret, nargs, args, hint, marshall_data);
+}
+
 CAMLprim value ml_g_closure_new (value clos)
 {
     GClosure* closure = g_closure_new_simple(sizeof(GClosure), (gpointer)clos);
@@ -567,6 +584,7 @@ CAMLprim value ml_g_object_set_property_dyn (value vobj, value prop, value arg)
   GType tp = internal_g_object_get_property_type(obj, String_val(prop));
   GValue val = {0};
   if (tp == G_TYPE_INVALID) return Val_unit; /* Silently ignore this error */
+  if (tp == G_TYPE_INVALID) printf("---- ERROR SET PROPERTY ----\n");
   g_value_init (&val, tp);
   g_value_set_mlvariant (&val, arg);
   g_object_set_property (obj, String_val(prop), &val);
